@@ -130,13 +130,28 @@
 #define TITRAQ_PREFSORTDIR      "sortascending"
 #define TITRAQ_DEFSORTDIR       true
 
+// Other value constants
+#define TITRAQ_DATAVERSIONMAJ   0
+#define TITRAQ_DATAVERSIONMIN   5
+
+// Environment string constants
+#define TITRAQ_ENVUSERNAME      "USER"
+#define TITRAQ_ENVHOMEDIR       "HOME"
+
 // Other string constants
-#define TITRAQ_DATEZERO         "0000-00-00"
 #define TITRAQ_SEPARATORTOK     " "
 #define TITRAQ_HOMEDIRTOK       "~/"
 #define TITRAQ_FEXTENSION       ".as"
+#define TITRAQ_DATAPATTERN      "%!AS-EVENTS-"
 #define TITRAQ_SAVEFIRST        "The timesheet contains unsaved changes.\nDo you want to save the changes or discard them?"
 #define TITRAQ_OVERWRITE        "A file already exists with the chosen name.\nDo you want to overwrite it with new data?"
+#define TITRAQ_NOPATTERNFOUND   "This data file appears to be invalid,\nbecause the AS data symbol\n        "
+#define TITRAQ_WASNOTFOUNDIN    "\nwas not found inside of it."
+#define TITRAQ_BADVERSIONMAJ    "Incompatible data format. Please\neither upgrade this application or\nthe data you are using with it."
+#define TITRAQ_BADVERSIONMIN    "Incompatible data format. Please either\nupgrade this application or downgrade\nthe data you are using with it."
+#define TITRAQ_INCOMPATDATA     "Error: incompatible data format."
+#define TITRAQ_INVALIDDATA      "Error: invalid data format."
+#define TITRAQ_SAVECANCELLED    "Warning: save operation failed, because the user cancelled."
 
 // Indexes of table columns
 #define TITRAQ_IDXALLCTRLS     -1
