@@ -51,7 +51,6 @@ Titraqform::Titraqform(QWidget *pParent, const char *kszName, WFlags Flags) :
     // Atenzione! Order is very important in the following sequence.
     // FIXME: Reorganize this procedural mess into self contained objects
     try {
-        int nUnhandled;         // Holds number of unhandled cmd args
         setupPrefs();           // Load general preferences
         setupActions();         // Create and initialize actions
         setupMenubar();         // Create and initialize menu bar
@@ -62,9 +61,6 @@ Titraqform::Titraqform(QWidget *pParent, const char *kszName, WFlags Flags) :
         setupEditlay();         // Create and initialize edit controls
         setupColumns();         // Prepare columns for viewing, sorting
         enableIface(false);     // Start things off in a empty state
-
-        nUnhandled = setupCmdargs(); // Parse the command line, and init file
-        setupInitdata(nUnhandled);   // Possibly open an inital event data file
     }
     catch (Genexcept& Genex) {
         Genex.reportErr();
