@@ -95,8 +95,9 @@ void Titraqform::pasteEntry(void)
 {
     int nRows = 0;              // Paste so many rows as are stored
     QString Selection;          // Will receive the clipboard text
-    QClipboard *pClip;          // Will reference the global clipboard
+    QClipboard *pClip = NULL;   // Will reference the global clipboard
 
+    pClip = QApplication::clipboard();                    // Prime the clips
     if (Selection = pClip->text(QClipboard::Clipboard)) { // Windows and Unix
         nRows = Selection.contains(QChar('\n'));    // How many rows
         this->addEntry(nRows);                      // Reuse slot
@@ -110,8 +111,11 @@ void Titraqform::pasteEntry(void)
         for (int nIter = 0; nIter < nRows; nIter++)
             this->validateData(m_pMaintable->currentRow() + nIter, 0);
 
+        m_pStatbar->message(QString::number(nRows) + trUtf8(" rows pasted"), 4000);
         updEdit(m_pMaintable->currentRow()); // Reflect in the update controls
     }
+    else // Well, I guess the user tried to paste an empty clipboard
+        m_pStatbar->message(trUtf8("The clipboard is empty"), 4000);
 }
 
 //
@@ -200,6 +204,21 @@ void Titraqform::addEntry(int nRows)
         m_pRefreshact->setEnabled(true);
         m_pCutact->setEnabled(true);
         m_pCopyact->setEnabled(true);
+
+        // Brighten all the edit controls also
+        m_pLineedit->setEnabled(true);
+        m_pUseredit->setEnabled(true);
+        m_pGuidedit->setEnabled(true);
+        m_pCrcedit->setEnabled(true);
+        m_pRevedit->setEnabled(true);
+        m_pDateedit->setEnabled(true);
+        m_pStarttime->setEnabled(true);
+        m_pEndtime->setEnabled(true);
+        m_pAmount->setEnabled(true);
+        m_pTasks->setEnabled(true);
+        m_pRemark->setEnabled(true);
+
+        // And optionally the RPC actions, too
 #ifdef HAVE_MICO
         m_pSynciiopact->setEnabled(true);
 #endif // HAVE_MICO
@@ -244,6 +263,22 @@ void Titraqform::delEntry(int nRows)
         m_pRefreshact->setEnabled(false);
         m_pCutact->setEnabled(false);
         m_pCopyact->setEnabled(false);
+
+        // Dim all the edit controls also
+        m_pStatusedit->setPixmap(s_kpcStatvoid_xpm);
+        m_pLineedit->setEnabled(false);
+        m_pUseredit->setEnabled(false);
+        m_pGuidedit->setEnabled(false);
+        m_pCrcedit->setEnabled(false);
+        m_pRevedit->setEnabled(false);
+        m_pDateedit->setEnabled(false);
+        m_pStarttime->setEnabled(false);
+        m_pEndtime->setEnabled(false);
+        m_pAmount->setEnabled(false);
+        m_pTasks->setEnabled(false);
+        m_pRemark->setEnabled(false);
+
+        // And optionally dim the RPC actions
 #ifdef HAVE_MICO
         m_pSynciiopact->setEnabled(false);
 #endif // HAVE_MICO
@@ -399,7 +434,7 @@ void Titraqform::saveFile(void)
                 return;                 // and short circuit
             }
             catch (Genexcept& Genex) {
-                Genex.reportErr();      // Report the error
+//                Genex.reportErr();      // Report the error
                 return;                 // and short circuit
             }
         }
@@ -538,6 +573,7 @@ void Titraqform::closeEvent(QCloseEvent *pClosit)
             this->saveFile();   // Save changes first
             break;
         case 1: // Don't save first
+            m_pMaintable->setDirty(false);
             break;
         case 2: // Do nothing
         default:
@@ -547,18 +583,22 @@ void Titraqform::closeEvent(QCloseEvent *pClosit)
         }
     }
 
-    // Fall through to implicit close code
-    this->setCaption(TITRAQ_APPTITLE);
-    try { // There might be problems, so wrap these last ops with error handling
-        if (this->isOpen())
-            m_pStatbar->message(trUtf8("Closed document ") + *this->getFilename(), 4000);
-        this->setOpen(false);       // Set doc state to closed
-        this->enableIface(false);   // Turn off the lights
+    if (!m_pMaintable->isDirty()) { // Check again
+        // Fall through to implicit close code
+        this->setCaption(TITRAQ_APPTITLE);
+        try { // There might be problems, so wrap these last ops with error handling
+            QString Lightsout;          // It's late, go to bed
+            if (this->isOpen())
+                Lightsout = trUtf8("Closed document ") + *this->getFilename();
+            this->setOpen(false);       // Set doc state to closed
+            this->enableIface(false);   // Turn off the lights
+            m_pStatbar->message(Lightsout, 4000);
+        }
+        catch (Genexcept& Genex) {
+            Genex.reportErr();
+        }
     }
-    catch (Genexcept& Genex) {
-        Genex.reportErr();
-    }
-    pClosit->ignore();              // Finish off by not closing
+    pClosit->ignore();  // Finish off by not closing
 }
 
 //
@@ -756,53 +796,59 @@ void Titraqform::calcCrc(int nRow, int nCol)
 //
 void Titraqform::updEdit(int nRow, int nCol)
 {
-//    QRegExp Shorten("/(\\w+)$");    // For stripping prefix off the current task
+    // Why is the app sending negative row signal? I don't know yet,
+    // so add in this nasty hack to fend off the debug spew on stderr
+    if (m_pMaintable->numRows() > 0 && nRow >= 0) {
+        // Field strings to check for validity and process
+        QString Textline(m_pMaintable->text(nRow, TITRAQ_IDXLINE));
+        QString Textuser(m_pMaintable->text(nRow, TITRAQ_IDXUSER));
+        QString Textguid(m_pMaintable->text(nRow, TITRAQ_IDXGUID));
+        QString Textcrc(m_pMaintable->text(nRow, TITRAQ_IDXCRC));
+        QString Textrev(m_pMaintable->text(nRow, TITRAQ_IDXREV));
+        QString Textdate(m_pMaintable->text(nRow, TITRAQ_IDXDATE));
+        QString Textstart(m_pMaintable->text(nRow, TITRAQ_IDXSTART));
+        QString Textfinish(m_pMaintable->text(nRow, TITRAQ_IDXFINISH));
+        QString Textamount(m_pMaintable->text(nRow, TITRAQ_IDXAMOUNT));
+        QString Texttask(m_pMaintable->text(nRow, TITRAQ_IDXTASK));
+        QString Textremark(m_pMaintable->text(nRow, TITRAQ_IDXREMARK));
 
-    // Field strings to check for validity and process
-    QString Textline(m_pMaintable->text(nRow, TITRAQ_IDXLINE));
-    QString Textuser(m_pMaintable->text(nRow, TITRAQ_IDXUSER));
-    QString Textguid(m_pMaintable->text(nRow, TITRAQ_IDXGUID));
-    QString Textcrc(m_pMaintable->text(nRow, TITRAQ_IDXCRC));
-    QString Textrev(m_pMaintable->text(nRow, TITRAQ_IDXREV));
-    QString Textdate(m_pMaintable->text(nRow, TITRAQ_IDXDATE));
-    QString Textstart(m_pMaintable->text(nRow, TITRAQ_IDXSTART));
-    QString Textfinish(m_pMaintable->text(nRow, TITRAQ_IDXFINISH));
-    QString Textamount(m_pMaintable->text(nRow, TITRAQ_IDXAMOUNT));
-    QString Texttask(m_pMaintable->text(nRow, TITRAQ_IDXTASK));
-    QString Textremark(m_pMaintable->text(nRow, TITRAQ_IDXREMARK));
+        // Reset the edition state member
+        m_pMaintable->setEdition();
 
-    // Reset the edition state member
-    m_pMaintable->setEdition();
+        // Set text of member edit controls
+        if (m_pMaintable->text(nRow, TITRAQ_IDXSTATUS).isEmpty())   // If row is empty
+            m_pStatusedit->setPixmap(s_kpcStatvoid_xpm);            // add a placeholder
+        else
+            m_pStatusedit->setPixmap(m_pMaintable->pixmap(nRow, TITRAQ_IDXSTATUS));
+        m_pLineedit->setText(Textline);
+        m_pUseredit->setText(Textuser);
+        m_pGuidedit->setText(Textguid);
+        m_pCrcedit->setText(Textcrc);
+        m_pRevedit->setText(Textrev);
 
-    // Set text of member edit controls
-    if (m_pMaintable->text(nRow, TITRAQ_IDXSTATUS).isEmpty())   // If row is empty
-        m_pStatusedit->setPixmap(s_kpcStatvoid_xpm);            // add a placeholder
+//        QRegExp Shorten("/(\\w+)$");    // For stripping prefix off the current task
+//        Texttask.remove(0, Shorten.search(Texttask) + 1); // Strip leading slash
+
+        m_pAmount->setText(Textamount);
+        m_pRemark->setText(Textremark);
+        m_pTasks->setCurrentText(Texttask);
+
+        // Members not suitable for empty string text
+        if (!Textdate.isEmpty())
+            m_pDateedit->setDate(QDate::fromString(Textdate, Qt::ISODate));
+        else
+            m_pDateedit->setDate(QDate::currentDate());
+        if (!Textstart.isEmpty())
+            m_pStarttime->setTime(QTime::fromString(Textstart, Qt::ISODate));
+        else
+            m_pStarttime->setTime(QTime::QTime(0, 0));
+        if (!Textfinish.isEmpty())
+            m_pEndtime->setTime(QTime::fromString(Textfinish, Qt::ISODate));
+        else
+            m_pEndtime->setTime(QTime::QTime(0, 0));
+    }
     else
-        m_pStatusedit->setPixmap(m_pMaintable->pixmap(nRow, TITRAQ_IDXSTATUS));
-    m_pLineedit->setText(Textline);
-    m_pUseredit->setText(Textuser);
-    m_pGuidedit->setText(Textguid);
-    m_pCrcedit->setText(Textcrc);
-    m_pRevedit->setText(Textrev);
-
-    m_pAmount->setText(Textamount);
-//    Texttask.remove(0, Shorten.search(Texttask) + 1); // Strip leading slash
-    m_pTasks->setCurrentText(Texttask);
-    m_pRemark->setText(Textremark);
-
-    // Members not suitable for empty string text
-    if (!Textdate.isEmpty())
-        m_pDateedit->setDate(QDate::fromString(Textdate, Qt::ISODate));
-    else
-        m_pDateedit->setDate(QDate::currentDate());
-    if (!Textstart.isEmpty())
-        m_pStarttime->setTime(QTime::fromString(Textstart, Qt::ISODate));
-    else
-        m_pStarttime->setTime(QTime::QTime(0, 0));
-    if (!Textfinish.isEmpty())
-        m_pEndtime->setTime(QTime::fromString(Textfinish, Qt::ISODate));
-    else
-        m_pEndtime->setTime(QTime::QTime(0, 0));
+        m_pStatbar->message(trUtf8("Empty timesheet, add entries first please"), 4000);
 }
 
 //
@@ -820,7 +866,7 @@ void Titraqform::validateData(int nRow, int nCol)
 {
     int nRealrow = -1;
 
-    if (!m_pMaintable->numRows() > 0) { // If no rows exist then short circuit
+    if (!this->isOpen()) { // If no data is loaded then short circuit
         m_pStatbar->message(trUtf8("Timesheet contains no data"), 4000);
         return;
     }
